@@ -310,6 +310,19 @@ class U128(ScaleType):
             raise ValueError('{} out of range for u128'.format(value))
 
 
+class U256(ScaleType):
+
+    def process(self):
+        return int(int.from_bytes(self.get_next_bytes(32), byteorder='little'))
+
+    def process_encode(self, value):
+
+        if 0 <= int(value) <= 2**256 - 1:
+            return ScaleBytes(bytearray(int(value).to_bytes(32, 'little')))
+        else:
+            raise ValueError('{} out of range for u256'.format(value))
+
+
 class I8(ScaleType):
 
     def process(self):
@@ -654,8 +667,7 @@ class BoxProposal(ScaleType):
             self.call_args.append({
                 'name': arg.name,
                 'type': arg.type,
-                'value': arg_type_obj.serialize(),
-                'valueRaw': arg_type_obj.raw_value
+                'value': arg_type_obj.serialize()
             })
 
         return {
@@ -1245,8 +1257,7 @@ class GenericCall(ScaleType):
             self.call_args.append({
                 'name': arg.name,
                 'type': arg.type,
-                'value': arg_type_obj.serialize(),
-                'valueRaw': arg_type_obj.raw_value
+                'value': arg_type_obj.serialize()
             })
 
         return {
@@ -1299,8 +1310,8 @@ class GenericCall(ScaleType):
 
 
 class GenericContractExecResult(Enum):
-    def __init__(self, data=None, data_scale_type=None, **kwargs):
-        self.data_scale_type = data_scale_type
+    def __init__(self, data=None, contract_result_scale_type=None, **kwargs):
+        self.contract_result_scale_type = contract_result_scale_type
         self.gas_consumed = None
         self.flags = None
         self.contract_result_data = None
@@ -1319,8 +1330,8 @@ class GenericContractExecResult(Enum):
 
     def process_encode(self, value):
 
-        if self.data_scale_type is None:
-            raise ValueError("Encoding is not possible because data_scale_type is not set")
+        if self.contract_result_scale_type is None:
+            raise ValueError("Encoding is not possible because 'contract_result_scale_type' is not set")
 
         if 'success' in value:
             value = {'Success': value['success']}
